package com.example.topse.fs;

import static org.junit.Assert.*;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

public class DummyFileSystemTest {

	DummyFileSystem filesystem = null;
	
	@Before
	public void setUp() throws Exception {
		filesystem = DummyFileSystem.getInstance();
		filesystem.clear();
	}

	@After
	public void tearDown() throws Exception {
	}

	@Test
	public void testRootShouldBeDirectoryAndEmptyName() {
		Directory node = filesystem.getRoot();
		
		assertEquals("", node.getName());
		assertTrue(node.isDirectory());
	}
	
	@Test
	public void testCreateFullPathForRoot() {
		Directory root = filesystem.getRoot();
		
		String rootPath = filesystem.getPath(root);
		
		assertEquals("/", rootPath);
	}
	
	@Test
	public void testCreateFullPathForTheChildrenOfRoot() {
		Directory root = filesystem.getRoot();
		Directory child = new Directory("abc");
		root.appendChild(child);
		
		String path = filesystem.getPath(child);
		
		assertEquals("/abc/", path);
	}

	@Test
	public void testCreateFullPathForTheDeppHierarchy() {
		Directory root = filesystem.getRoot();
		Directory node1 = new Directory("abc");
		root.appendChild(node1);
		Directory node2 = new Directory("def");
		node1.appendChild(node2);
		Directory node3 = new Directory("ghi");
		node2.appendChild(node3);
		Directory node4 = new Directory("jkl");
		node3.appendChild(node4);
		
		String path = filesystem.getPath(node4);

		assertEquals("/abc/def/ghi/jkl/", path);
	}
	
	@Test
	public void testClearEraseAllFileNodes() {
		Directory root = filesystem.getRoot();
		root.appendChild(new Directory("abc"));
		root.appendChild(new File("xyz"));
		
		filesystem.clear();
		
		assertEquals(0, root.getChildren().size());
	}
	
}
