package com.example.topse.shell;

import java.io.ByteArrayInputStream;
import java.io.InputStream;

import org.junit.Test;

import com.example.topse.fs.Directory;
import com.example.topse.fs.DummyFileSystem;

import junit.framework.TestCase;

public class DummyShellTest extends TestCase {
	
	DummyShell shell = new DummyShell();

	protected void setUp() throws Exception {
	}

	protected void tearDown() throws Exception {
	}

	@Test
	public void testGetInputReadsInputStream() {
		InputStream stream = new ByteArrayInputStream("java".getBytes());
		shell.setInputStream(stream);
	
		String inputString = shell.getInput();

		assertTrue(inputString.equals("java"));	
	}

	@Test
	public void testGetInputTrimTheExtraSpaces() {
		InputStream stream = new ByteArrayInputStream("  java  ".getBytes());
		shell.setInputStream(stream);
	
		String inputString = shell.getInput();

		assertEquals("java", inputString);	
	}
	
	@Test
	public void testExecuteFinishByExitCommand() {
		assertTrue(shell.executeCommand("exit", null));
		assertTrue(shell.getFinished());
	}

	@Test
	public void testExecuteNotFinishUntilExitCommand() {
		assertFalse(shell.executeCommand("abc", null));
		assertFalse(shell.getFinished());
	}
	
	@Test
	public void testCurrentDirectoryShouldBeRootAtFirst() {
		Directory currentDirectory = this.shell.getCurrentDirectory();

		DummyFileSystem filesystem = DummyFileSystem.getInstance();
		assertTrue(filesystem.isRoot(currentDirectory));
	}
	
	@Test
	public void testShellHandlePWDCommand() {
		assertTrue(shell.executeCommand("pwd", null));
	}
	
	@Test
	public void testShellHandleMkdirCommand() {
		assertTrue(shell.executeCommand("mkdir", new String[] { "abc" }));
	}
	
	@Test
	public void testParseInputCommandWithoutArguments() {
		String[] items = shell.parseCommand("xyz");
		
		assertEquals(1, items.length);
		assertEquals("xyz", items[0]);
	}

	@Test
	public void testParseInputCommandWith1Argument() {
		String[] items = shell.parseCommand("abc def");
		
		assertEquals(2, items.length);
		assertEquals("abc", items[0]);
		assertEquals("def", items[1]);
	}

}
