package com.example.topse.shell.commands;

import static org.junit.Assert.*;

import org.jmock.Expectations;
import org.jmock.Mockery;
import org.jmock.Sequence;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import com.example.topse.fs.Directory;
import com.example.topse.fs.DummyFileSystem;
import com.example.topse.fs.File;
import com.example.topse.shell.Shell;

public class LsCommandTest {

	LsCommand command = new LsCommand();
	Mockery context = new Mockery();
	Shell shell = context.mock(Shell.class);

	DummyFileSystem filesystem = null;
	
	@Before
	public void setUp() throws Exception {
		filesystem = DummyFileSystem.getInstance();
		filesystem.clear();
	}

	@After
	public void tearDown() throws Exception {
	}

	@Test
	public void testDoesNotHandleNotLsCommand() {
		boolean isFinished = command.execute(shell, "not_ls", null);

		assertFalse(isFinished);
	}

	@Test
	public void testDoNothingIfThereIsNoItemsInTheCurrentDirectory() {
		final Directory dir = new Directory("root");
		context.checking(new Expectations() {
			{
				oneOf(shell).getCurrentDirectory();
				will(returnValue(dir));
			}
		});

		boolean isFinished = command.execute(shell, "ls", null);

		assertTrue(isFinished);
	}

	@Test
	public void testShowDirectoriesUnderTheCurrentDirectory() {
		final Directory dir = filesystem.getRoot();
		dir.appendChild(new Directory("abc"));
		dir.appendChild(new Directory("def"));
		dir.appendChild(new File("xyz"));
		final Sequence seq = context.sequence("seq");
		context.checking(new Expectations() { {
			oneOf(shell).getCurrentDirectory(); will(returnValue(dir));
			oneOf(shell).write("abc/"); inSequence(seq);
			oneOf(shell).write("def/"); inSequence(seq);
			oneOf(shell).write("xyz"); inSequence(seq);
		}});

		boolean isFinished = command.execute(shell, "ls", null);

		context.assertIsSatisfied();
		assertTrue(isFinished);
	}

}
