package com.example.topse.shell.commands;

import static org.junit.Assert.*;

import java.util.List;

import org.jmock.Expectations;
import org.jmock.Mockery;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import com.example.topse.fs.Directory;
import com.example.topse.fs.FileNode;
import com.example.topse.shell.Shell;

public class MkdirCommandTest {
	
	MkdirCommand command = new MkdirCommand();
	Mockery context = new Mockery();
	Shell shell = context.mock(Shell.class);

	@Before
	public void setUp() throws Exception {
	}

	@After
	public void tearDown() throws Exception {
	}

	@Test
	public void testEnableToMakeDirectoryUnderTheCurrentDirectory() {
		final Directory dir = new Directory("parent");
		context.checking(new Expectations () {{
			oneOf (shell).getCurrentDirectory(); will(returnValue(dir));		
		}});
		
		boolean isFinished = command.execute(shell, "mkdir", new String[] { "child" });

		assertTrue(isFinished);
		context.assertIsSatisfied();
		List<FileNode> nodes = dir.getChildren();
		assertEquals(1, nodes.size());
		FileNode node = nodes.get(0);
		assertTrue(node.isDirectory());
		assertEquals("child", node.getName());
	}
	
	@Test
	public void testFailedToMakeDirectoryWithoutName() {
		final Directory dir = new Directory("parent");
		context.checking(new Expectations () {{
			oneOf (shell).write("Invalid Arguments");
		}});
		
		boolean isFinished = command.execute(shell, "mkdir", null);

		assertTrue(isFinished);
		context.assertIsSatisfied();
		assertEquals(0, dir.getChildren().size());
	}
	
	@Test
	public void testDoesNotHandleNotMkdirCommand() {
		assertFalse(command.execute(shell, "not_mkdir", null));
	}

}
